# solarwinds_apm
SolarWinds Observability distribution of OpenTelemetry Python, providing automatic instrumentation of Python applications for APM.

Online documentation on SolarWinds APM features, configuration, and more is coming soon.
